==> v1.5.0.tar.gz: apk-editor-studio/AUTHORS.md <==
# Authors

### Author:

- [Alexander Gorishnyak](https://github.com/kefir500)

### Special Thanks:

- [Connor Tumbleson](https://github.com/iBotPeaches) and [contributors](https://github.com/iBotPeaches/Apktool/blob/master/CONTRIBUTORS.md) — Apktool
- [Frank Osterfeld](https://github.com/frankosterfeld) — QtKeychain
- [Icons8](https://icons8.com) — Action icons
- [Mark James](http://www.famfamfam.com) — Flag icons

### Translators:

#### Azerbaijani
- [Emin Huseynzade](https://www.transifex.com/user/profile/ehsynze/)

#### Chinese (Simplified)
- [Wang Chenxu](http://www.dayanzai.me)

#### Czech
- [Michal Mrnka](https://www.transifex.com/user/profile/Mimrixerix/)

#### French
- [Julien Veuillet](https://www.wakdev.com)

#### German
- [Till Tektronix](https://www.transifex.com/user/profile/Tektronix/)
- [daywalk3r666](https://www.transifex.com/user/profile/daywalk3r666/)

#### Greek
- [Spiros Kaparos](https://www.transifex.com/user/profile/spkprs/)

#### Hebrew
- [Tomer Shami](https://www.transifex.com/user/profile/PointApps/)

#### Hungarian
- [Egyed Ferenc](https://www.transifex.com/user/profile/efi99/)
- [Szepesfalvy Kristóf](https://www.transifex.com/user/profile/szkristof/)

#### Indonesian
- [Triyan W. Nugroho](https://www.transifex.com/user/profile/TriyanWahyuNugroho/)

#### Italian
- [bovirus](https://www.transifex.com/user/profile/bovirus/)
- [Davide Pedretti Biagioni](https://www.transifex.com/user/profile/davide.pedrettibiagioni/)

#### Japanese
- [Sakai Hiroki](https://www.transifex.com/user/profile/m07jp/)

#### Korean
- [Gyuha Shin](https://www.transifex.com/user/profile/gyuha/)

#### Kurdish
- [Erfan Ski](https://www.transifex.com/user/profile/erfan13/)

#### Persian
- [SSLRI](https://www.transifex.com/user/profile/sslri/)
- [Milad19s](https://www.transifex.com/user/profile/Milad19s/)

#### Polish
- [Jerzy Puczek](https://www.transifex.com/user/profile/Jurek04/)

#### Portuguese
- [Giancarlo Molinari](https://www.transifex.com/user/profile/pombimsjb/)

#### Romanian
- [Codrut X](https://www.transifex.com/user/profile/codrut2020/)

#### Russian
- [Alexander Gorishnyak](https://www.transifex.com/user/profile/kefir500/)

#### Spanish
- [Francisco Zamorano](https://www.transifex.com/user/profile/Paco_Zamo/)
- [Jose Osuna](https://www.transifex.com/user/profile/itp.osuna/)

#### Turkish
- [emre1393](https://www.transifex.com/user/profile/emre1393/)

### Supporters:

You can see the full list of supporters and their donations [here](https://qwertycube.com/donate/).

==> v1.6.0.tar.gz: apk-editor-studio/AUTHORS.md <==
# Authors

### Author:

- [Alexander Gorishnyak](https://github.com/kefir500)

### Contributors:

- [Sukhmeet Singh](https://github.com/MadGuyyy)

### Special Thanks:

- [Connor Tumbleson](https://github.com/iBotPeaches) and [contributors](https://github.com/iBotPeaches/Apktool/blob/master/CONTRIBUTORS.md) — Apktool
- [The KDE Community](https://kde.org/community/whatiskde/) — KSyntaxHighlighting
- [Frank Osterfeld](https://github.com/frankosterfeld) — QtKeychain
- [Itay Grudev](https://github.com/itay-grudev) — SingleApplication
- [Juergen Skrotzky](https://github.com/Jorgen-VikingGod) — DarkStyle
- [Icons8](https://icons8.com) — Action icons
- [Mark James](http://www.famfamfam.com) — Flag icons

### Translators:

#### Azerbaijani
- [Emin Huseynzade](https://www.transifex.com/user/profile/ehsynze/)

#### Chinese (Simplified)
- [Wang Chenxu](http://www.dayanzai.me)

#### Czech
- [Michal Mrnka](https://www.transifex.com/user/profile/Mimrixerix/)

#### French
- [Julien Veuillet](https://www.wakdev.com)

#### German
- [Till Tektronix](https://www.transifex.com/user/profile/Tektronix/)
- [daywalk3r666](https://www.transifex.com/user/profile/daywalk3r666/)

#### Greek
- [Spiros Kaparos](https://www.transifex.com/user/profile/spkprs/)

#### Hebrew
- [Tomer Shami](https://www.transifex.com/user/profile/PointApps/)

#### Hungarian
- [Egyed Ferenc](https://www.transifex.com/user/profile/efi99/)
- [Szepesfalvy Kristóf](https://www.transifex.com/user/profile/szkristof/)

#### Indonesian
- [Triyan W. Nugroho](https://www.transifex.com/user/profile/TriyanWahyuNugroho/)

#### Italian
- [bovirus](https://www.transifex.com/user/profile/bovirus/)
- [Davide Pedretti Biagioni](https://www.transifex.com/user/profile/davide.pedrettibiagioni/)

#### Japanese
- [Sakai Hiroki](https://www.transifex.com/user/profile/m07jp/)

#### Korean
- [Gyuha Shin](https://www.transifex.com/user/profile/gyuha/)

#### Kurdish
- [Erfan Sci](https://www.transifex.com/user/profile/erfan13/)

#### Persian
- [SSLRI](https://www.transifex.com/user/profile/sslri/)
- [Milad19s](https://www.transifex.com/user/profile/Milad19s/)

#### Polish
- [Jerzy Puczek](https://www.transifex.com/user/profile/Jurek04/)

#### Portuguese
- [Giancarlo Molinari](https://www.transifex.com/user/profile/pombimsjb/)

#### Romanian
- [Codrut X](https://www.transifex.com/user/profile/codrut2020/)

#### Russian
- [Alexander Gorishnyak](https://www.transifex.com/user/profile/kefir500/)

#### Spanish
- [Francisco Zamorano](https://www.transifex.com/user/profile/Paco_Zamo/)
- [Jose Osuna](https://www.transifex.com/user/profile/itp.osuna/)

#### Turkish
- [emre1393](https://www.transifex.com/user/profile/emre1393/)

### Supporters:

You can see the full list of supporters and their donations [here](https://qwertycube.com/donate/).
